## Community Resources

### Talks

- [EuroPython 2022](https://www.youtube.com/watch?v=AutugvJNVkY&)
- [GeoPython 2022](https://www.youtube.com/watch?v=YCpbCQwbkd4)
- [PyCon US 2022](https://youtu.be/1IiL31tUEVk?t=2101)
- [PyCon Sweden 2021](https://www.youtube.com/watch?v=DK9teAs72Do)

### Blogs

- [Hello, Robyn!](https://www.sanskar.me/posts/hello-robyn)

### Upcoming Talks

- Coming Soon...
